@@ -5,7 +5,7 @@ import re
 
 NW = re.compile(r'\W')
 
-def GetLinks(url, proxy=None):
+def GetLinks(url, proxy=None, text=False):
     doc = None
     basehost = None
     if url.startswith("http"):
@@ -15,19 +15,24 @@ def GetLinks(url, proxy=None):
             sess.proxies['http'] = sess.proxies['https'] = proxy
         doc = PyQuery(sess.get(url).text)
     else:
-        with open(url) as fp:
-            doc = PyQuery(fp.read())
+        if text == False:
+            with open(url) as fp:
+                text = fp.read()
+        else:
+            text = url
+        doc = PyQuery(text)
     if doc == None:
         doc = PyQuery("<html></html>")
     for l in doc("a[href]"):
         link = l.attrib['href']
         if link  == "#":continue
         if link.startswith("http") or link.startswith("//"):
-            res = up.urlsplit(url)
-            if basehost != None and res.hostname != basehost:continue
-        yield link
+            if not text:
+                res = up.urlsplit(url)
+                if basehost != None and res.hostname != basehost:continue
+        yield link,l.text
+
 
-        
 class Url(str):
     urls = {}
     def __init__(self, url):
@@ -36,6 +41,7 @@ class Url(str):
         self.no_w = set(NW.findall(url))
         self.w = set(url)
         self.host = up.urlsplit(url).hostname
+        self.rank = len(self.no_w)
         # self._like = []
         Url.urls[url] = self
     
@@ -79,7 +85,7 @@ class Url(str):
     @classmethod
     def group(cls, urls, distance=0.2):
         urls_g = dict()
-        last = None
+        # last = None
         for i in urls:
             ui = Url(i)
             urls_g[i] = set()
@@ -109,15 +115,18 @@ class Url(str):
         return list(urls_g.values())
     
     @classmethod
-    def Index(cls, url, distance=0.2):
-        host = up.urlsplit(url)
+    def Index(cls, url, distance=0.2, rank=2):
         ls = []
-
-        for l in GetLinks(url):
-            ls.append(l)
-        #     if l.startswith("http"):
-        #         ls.append(l)
-        #     else:
-        #         ls.append(up.urljoin(host.scheme + "://" + host.hostname, l))
+        if not isinstance(url, (list, tuple)):
+            for l  in GetLinks(url):
+                if isinstance(l, (list, tuple)):
+                    l = l[0]
+                
+                ls.append(l)
+        else:
+            ls = url
         res = cls.group(ls, distance=distance)
-        return sorted(res, key=lambda i:len(i), reverse=True)
\ No newline at end of file
+        res =  sorted(res, key=lambda i:len(i) + list(i)[0].rank * 20, reverse=True)
+        if rank < len(res):
+            return res[:rank]
+        return res
\ No newline at end of file
